[patch 17/26] Dynamic kernel command-line - ppc

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Rename saved_command_line into boot_command_line.

Signed-off-by: Alon Bar-Lev <[email protected]>

---
 arch/ppc/kernel/setup.c         |    2 +-
 arch/ppc/platforms/lopec.c      |    2 +-
 arch/ppc/platforms/pplus.c      |    2 +-
 arch/ppc/platforms/prep_setup.c |    4 ++--
 4 files changed, 5 insertions(+), 5 deletions(-)

Index: linux-2.6.20-rc4-mm1/arch/ppc/kernel/setup.c
===================================================================
--- linux-2.6.20-rc4-mm1.orig/arch/ppc/kernel/setup.c
+++ linux-2.6.20-rc4-mm1/arch/ppc/kernel/setup.c
@@ -543,7 +543,7 @@ void __init setup_arch(char **cmdline_p)
 	init_mm.brk = (unsigned long) klimit;
 
 	/* Save unparsed command line copy for /proc/cmdline */
-	strlcpy(saved_command_line, cmd_line, COMMAND_LINE_SIZE);
+	strlcpy(boot_command_line, cmd_line, COMMAND_LINE_SIZE);
 	*cmdline_p = cmd_line;
 
 	parse_early_param();
Index: linux-2.6.20-rc4-mm1/arch/ppc/platforms/lopec.c
===================================================================
--- linux-2.6.20-rc4-mm1.orig/arch/ppc/platforms/lopec.c
+++ linux-2.6.20-rc4-mm1/arch/ppc/platforms/lopec.c
@@ -344,7 +344,7 @@ lopec_setup_arch(void)
 		 if (bootargs != NULL) {
 			 strcpy(cmd_line, bootargs);
 			 /* again.. */
-			 strcpy(saved_command_line, cmd_line);
+			 strcpy(boot_command_line, cmd_line);
 		}
 	}
 #endif
Index: linux-2.6.20-rc4-mm1/arch/ppc/platforms/pplus.c
===================================================================
--- linux-2.6.20-rc4-mm1.orig/arch/ppc/platforms/pplus.c
+++ linux-2.6.20-rc4-mm1/arch/ppc/platforms/pplus.c
@@ -592,7 +592,7 @@ static void __init pplus_setup_arch(void
 		if (bootargs != NULL) {
 			strcpy(cmd_line, bootargs);
 			/* again.. */
-			strcpy(saved_command_line, cmd_line);
+			strcpy(boot_command_line, cmd_line);
 		}
 	}
 #endif
Index: linux-2.6.20-rc4-mm1/arch/ppc/platforms/prep_setup.c
===================================================================
--- linux-2.6.20-rc4-mm1.orig/arch/ppc/platforms/prep_setup.c
+++ linux-2.6.20-rc4-mm1/arch/ppc/platforms/prep_setup.c
@@ -634,7 +634,7 @@ static void __init prep_init_sound(void)
 	/*
 	 * Find a way to push these informations to the cs4232 driver
 	 * Give it out with printk, when not in cmd_line?
 	 * Append it to  cmd_line and saved_command_line?
 	 * Format is cs4232=io,irq,dma,dma2
 	 */
 }
@@ -897,7 +897,7 @@ prep_setup_arch(void)
 		 if (bootargs != NULL) {
 			 strcpy(cmd_line, bootargs);
 			 /* again.. */
-			 strcpy(saved_command_line, cmd_line);
+			 strcpy(boot_command_line, cmd_line);
 		}
 	}
 
@@ -634,7 +634,7 @@ static void __init prep_init_sound(void)
 	 * Find a way to push these informations to the cs4232 driver
 	 * Give it out with printk, when not in cmd_line?
-	 * Append it to  cmd_line and saved_command_line?
+	 * Append it to  cmd_line and boot_command_line?
 	 * Format is cs4232=io,irq,dma,dma2
 	 */

-- 
-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

[Index of Archives]     [Kernel Newbies]     [Netfilter]     [Bugtraq]     [Photo]     [Stuff]     [Gimp]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Video 4 Linux]     [Linux for the blind]     [Linux Resources]
  Powered by Linux